pub type Hkdf<H> = GenericHkdf<Hmac<H>>;Expand description
GenericHkdf variant which uses Hmac for the underlying HMAC implementation.
Aliased Type
pub struct Hkdf<H> { /* private fields */ }pub type Hkdf<H> = GenericHkdf<Hmac<H>>;GenericHkdf variant which uses Hmac for the underlying HMAC implementation.
pub struct Hkdf<H> { /* private fields */ }